@@ -20,6 +20,7 @@
 
 #include "Frame_Resizer_Extended.h"
 #include "FileSystem.h"
+#include "OptionComboBox.h"
 #include "Partition.h"
 
 #include <gtkmm/dialog.h>
@@ -28,8 +29,6 @@
 #include <gtkmm/spinbutton.h>
 #include <gtkmm/table.h>
 #include <gtkmm/box.h>
-#include <gtkmm/tooltips.h>
-#include <gtkmm/optionmenu.h>
 
 namespace GParted
 {
@@ -72,8 +71,7 @@ protected:
 
 	Gtk::HBox hbox_main ;
 	Gtk::SpinButton spinbutton_before, spinbutton_size, spinbutton_after;
-	Gtk::OptionMenu optionmenu_alignment ;
-	Gtk::Menu menu_alignment ;
+	OptionComboBox combo_alignment;
 
 	sigc::connection before_change_connection, size_change_connection, after_change_connection ;
 
