@@ -20,9 +20,9 @@
 
 #include "Dialog_Base_Partition.h"
 #include "Device.h"
+#include "OptionComboBox.h"
 #include "Partition.h"
-
-#include <gtkmm/optionmenu.h>
+#include "Utils.h"
 
 namespace GParted
 {
@@ -49,18 +49,19 @@ private:
 	               bool any_extended,
 	               unsigned short new_count,
 	               const std::vector<FS> & FILESYSTEMS );
-	void Build_Filesystems_Menu( bool only_unformatted ) ;
-	
+	void build_filesystems_combo(bool only_unformatted);
+	Byte_Value get_filesystem_min_limit( FSType fstype );
+
 	Gtk::Table table_create;
-	Gtk::OptionMenu optionmenu_type, optionmenu_filesystem;
-	Gtk::Menu menu_type, menu_filesystem;
+	OptionComboBox combo_type;
+	OptionComboBox combo_filesystem;
 	Gtk::Entry partition_name_entry;
 	Gtk::Entry filesystem_label_entry;
 
 	std::vector<FS> FILESYSTEMS ;
 	
 	//signal handlers
-	void optionmenu_changed( bool );
+	void combobox_changed(bool);
 
 	unsigned short new_count, first_creatable_fs ;
 };
