@@ -22,6 +22,11 @@
 #include <gtkmm/drawingarea.h>
 #include <gdkmm/cursor.h>
  
+
+namespace GParted
+{
+
+
 class Frame_Resizer_Base : public Gtk::Frame
 {
 public:
@@ -47,7 +52,9 @@ public:
 	int get_x_start() ;
 	int get_x_end() ;
 
-	virtual void Draw_Partition() ;
+	virtual void draw_partition(const Cairo::RefPtr<Cairo::Context>& cr);
+
+	void redraw();
 
 	//public signals  (emitted upon resize/move)
 	sigc::signal<void,int,int, ArrowType> signal_resize;
@@ -66,13 +73,10 @@ protected:
 	bool drawingarea_on_button_press_event( GdkEventButton * ev ) ;
 	bool drawingarea_on_button_release_event( GdkEventButton * ev ) ;
 	bool drawingarea_on_leave_notify( GdkEventCrossing * ev ) ;
-		
-	void Draw_Resize_Grip( ArrowType ) ;
+
+	void draw_resize_grip(const Cairo::RefPtr<Cairo::Context>& cr, ArrowType);
 
 	Gtk::DrawingArea drawingarea ;
-	Glib::RefPtr<Gdk::GC> gc_drawingarea ;
-	Glib::RefPtr<Gdk::Pixmap> pixmap ;
-	Glib::RefPtr<Gdk::GC> gc_pixmap ;
 
 	Gdk::Color color_used, color_unused, color_arrow, color_background, color_partition, color_arrow_rectangle;
 
@@ -88,4 +92,7 @@ private:
 
 };
 
+
+} //GParted
+
 #endif /* GPARTED_FRAME_RESIZER_BASE_H */
