@@ -60,47 +60,51 @@ extern const Glib::ustring DEV_MAPPER_PATH;
 enum FSType
 {
 	// Special partition types and functions
-	FS_UNALLOCATED     = 0,
-	FS_UNKNOWN         = 1,
-	FS_UNFORMATTED     = 2,
-	FS_CLEARED         = 3,  //Clear existing file system signatures
-	FS_EXTENDED        = 4,
+	FS_UNSUPPORTED     = 0,  // Type with no supported actions
+	FS_UNALLOCATED     = 1,  // Unallocated space on a partitioned drive
+	FS_UNKNOWN         = 2,  // Unrecognised content in a drive or partition
+	FS_UNFORMATTED     = 3,  // Create a partition without a file system
+	FS_CLEARED         = 4,  // Clear existing file system signatures
+	FS_OTHER           = 5,  // Just for showing in the File System Support dialog
+	FS_EXTENDED        = 6,
 
-	// Supported file system types
-	FS_BTRFS           = 5,
-	FS_EXFAT           = 6, /* Also known as fat64 */
-	FS_EXT2            = 7,
-	FS_EXT3            = 8,
-	FS_EXT4            = 9,
-	FS_F2FS            = 10,
-	FS_FAT16           = 11,
-	FS_FAT32           = 12,
-	FS_HFS             = 13,
-	FS_HFSPLUS         = 14,
-	FS_JFS             = 15,
-	FS_LINUX_SWAP      = 16,
-	FS_LUKS            = 17,
-	FS_LVM2_PV         = 18,
-	FS_NILFS2          = 19,
-	FS_NTFS            = 20,
-	FS_REISER4         = 21,
-	FS_REISERFS        = 22,
-	FS_UDF             = 23,
-	FS_UFS             = 24,
-	FS_XFS             = 25,
+	// Fully supported file system types
+	FS_BTRFS           = 7,
+	FS_EXFAT           = 8, /* Also known as fat64 */
+	FS_EXT2            = 9,
+	FS_EXT3            = 10,
+	FS_EXT4            = 11,
+	FS_F2FS            = 12,
+	FS_FAT16           = 13,
+	FS_FAT32           = 14,
+	FS_HFS             = 15,
+	FS_HFSPLUS         = 16,
+	FS_JFS             = 17,
+	FS_LINUX_SWAP      = 18,
+	FS_LUKS            = 19,
+	FS_LVM2_PV         = 20,
+	FS_MINIX           = 21,
+	FS_NILFS2          = 22,
+	FS_NTFS            = 23,
+	FS_REISER4         = 24,
+	FS_REISERFS        = 25,
+	FS_UDF             = 26,
+	FS_XFS             = 27,
 
-	// Recognised signatures but otherwise unsupported file system types
-	FS_BITLOCKER       = 26,
-	FS_GRUB2_CORE_IMG  = 27,
-	FS_ISO9660         = 28,
-	FS_LINUX_SWRAID    = 29,
-	FS_LINUX_SWSUSPEND = 30,
-	FS_REFS            = 31,
-	FS_ZFS             = 32,
+	// Other recognised file system types
+	FS_APFS            = 28,
+	FS_BITLOCKER       = 29,
+	FS_GRUB2_CORE_IMG  = 30,
+	FS_ISO9660         = 31,
+	FS_LINUX_SWRAID    = 32,
+	FS_LINUX_SWSUSPEND = 33,
+	FS_REFS            = 34,
+	FS_UFS             = 35,
+	FS_ZFS             = 36,
 
 	// Partition space usage colours
-	FS_USED            = 33,
-	FS_UNUSED          = 34
+	FS_USED            = 37,
+	FS_UNUSED          = 38
 } ;
 
 enum SIZE_UNIT
