@@ -22,8 +22,9 @@
 #include "Utils.h"
 #include "btrfs.h"
 
-#include <gtk/gtk.h>
 #include <gtkmm/alignment.h>
+#include <gtkmm/viewport.h>
+#include <gdkmm/general.h>
 
 namespace GParted
 {
@@ -53,11 +54,10 @@ Dialog_Partition_Info::Dialog_Partition_Info( const Partition & partition ) : pa
 	//As Gtk::VBox widget info_msg_vbox doesn't have a native scrolling capability a
 	//  Gtk::Viewport is automatically created to contain it when it is added to the
 	//  Gtk::ScrolledWindow widget info_scrolled.  The Viewport widget is created with
-	//  shadow type GTK_SHADOW_IN by default.  Change to GTK_SHADOW_NONE.  Have to use
-	//  GTK+ C API as the Viewport widget isn't exposed via gtkmm C++ API.
-	//  https://developer.gnome.org/gtkmm/2.24/classGtk_1_1ScrolledWindow.html#a17c588d56d93923841d38f0d5e2ec9d7
-	GtkWidget * scrollable_child = gtk_bin_get_child(GTK_BIN(info_scrolled.gobj()));
-	gtk_viewport_set_shadow_type(GTK_VIEWPORT(scrollable_child), GTK_SHADOW_NONE);
+	//  shadow type GTK_SHADOW_IN by default.  Change to GTK_SHADOW_NONE.
+	Gtk::Viewport * child_viewport = dynamic_cast<Gtk::Viewport *>(info_scrolled.get_child());
+	if (child_viewport)
+		child_viewport->set_shadow_type(Gtk::SHADOW_NONE);
 	//horizontally center the information scrolled window to match partition graphic
 	Gtk::Alignment * center_widget = manage( new Gtk::Alignment(0.5, 0.5, 0.0, 1.0) ) ;
 	center_widget ->add( info_scrolled ) ;
@@ -117,41 +117,62 @@ Dialog_Partition_Info::Dialog_Partition_Info( const Partition & partition ) : pa
 	this ->show_all_children() ;
 }
 
-void Dialog_Partition_Info::drawingarea_on_realize()
-{
-	gc = Gdk::GC::create( drawingarea .get_window() ) ;
-	
-	drawingarea .get_window() ->set_background( color_partition ) ;
-}
 
 bool Dialog_Partition_Info::drawingarea_on_expose( GdkEventExpose *ev )
 {
+	Glib::RefPtr<Gdk::Window> window = drawingarea.get_window();
+	if (!window)
+		return true;
+
+	Cairo::RefPtr<Cairo::Context> cr = window->create_cairo_context();
+
+	// Clip to the area indicated by the expose event so that we only redraw
+	// the portion of the window that needs to be redrawn.
+	cr->rectangle(ev->area.x, ev->area.y, ev->area.width, ev->area.height);
+	cr->clip();
+
+	Gdk::Cairo::set_source_color(cr, color_partition);
+	cr->rectangle(0, 0, 400, 60);
+	cr->fill();
+
 	if ( partition.filesystem != FS_UNALLOCATED )
 	{
-		//used
-		gc ->set_foreground( color_used );
-		drawingarea .get_window() ->draw_rectangle( gc, true, BORDER, BORDER, used, 44 ) ;
-		
-		//unused
-		gc ->set_foreground( color_unused );
-		drawingarea .get_window() ->draw_rectangle( gc, true, BORDER + used, BORDER, unused, 44 ) ;
+		// Used
+		Gdk::Cairo::set_source_color(cr, color_used);
+		cr->rectangle(BORDER,
+		              BORDER,
+		              used,
+		              60 - 2 * BORDER);
+		cr->fill();
 
-		//unallocated
-		gc ->set_foreground( color_unallocated );
-		drawingarea .get_window() ->draw_rectangle( gc, true, BORDER + used + unused, BORDER, unallocated, 44 ) ;
+		// Unused
+		Gdk::Cairo::set_source_color(cr, color_unused);
+		cr->rectangle(BORDER + used,
+		              BORDER,
+		              unused,
+		              60 - 2 * BORDER);
+		cr->fill();
+
+		// Unallocated
+		Gdk::Cairo::set_source_color(cr, color_unallocated);
+		cr->rectangle(BORDER + used + unused,
+		              BORDER,
+		              unallocated,
+		              60 - 2 * BORDER);
+		cr->fill();
 	}
-	
-	//text
-	gc ->set_foreground( color_text );
-	drawingarea .get_window() ->draw_layout( gc, 180, BORDER + 6, pango_layout ) ;
-	
+
+	// Text
+	Gdk::Cairo::set_source_color(cr, color_text);
+	cr->move_to(180, BORDER + 6);
+	pango_layout->show_in_cairo_context(cr);
+
 	return true;
 }
 
 void Dialog_Partition_Info::init_drawingarea() 
 {
 	drawingarea .set_size_request( 400, 60 ) ;
-	drawingarea .signal_realize().connect( sigc::mem_fun(*this, &Dialog_Partition_Info::drawingarea_on_realize) ) ;
 	drawingarea .signal_expose_event().connect( sigc::mem_fun(*this, &Dialog_Partition_Info::drawingarea_on_expose) ) ;
 	
 	frame = manage( new Gtk::Frame() ) ;
@@ -165,7 +186,7 @@ void Dialog_Partition_Info::init_drawingarea()
 	this ->get_vbox() ->pack_start( *hbox, Gtk::PACK_SHRINK ) ;
 	
 	//calculate proportional width of used, unused and unallocated
-	if ( partition .type == GParted::TYPE_EXTENDED )
+	if (partition.type == TYPE_EXTENDED)
 	{
 		//Specifically show extended partitions as unallocated
 		used        = 0 ;
@@ -184,22 +205,13 @@ void Dialog_Partition_Info::init_drawingarea()
 		unallocated = 0 ;
 	}
 	
-	//allocate some colors
-	color_used.set( "#F8F8BA" );
-	this ->get_colormap() ->alloc_color( color_used ) ;
-	
-	color_unused .set( "white" ) ;
-	this ->get_colormap() ->alloc_color( color_unused ) ;
-
-	color_unallocated .set( "darkgrey" ) ;
-	this ->get_colormap() ->alloc_color( color_unallocated ) ;
-
-	color_text .set( "black" );
-	this ->get_colormap() ->alloc_color( color_text ) ;
-
+	// Colors
+	color_used.set("#F8F8BA");
+	color_unused.set("white");
+	color_unallocated.set("darkgrey");
+	color_text.set("black");
 	color_partition.set( Utils::get_color( partition.get_filesystem_partition().filesystem ) );
-	this ->get_colormap() ->alloc_color( color_partition ) ;	 
-	
+
 	//set text of pangolayout
 	pango_layout = drawingarea .create_pango_layout( 
 		partition .get_path() + "\n" + Utils::format_size( partition .get_sector_length(), partition .sector_size ) ) ;
@@ -598,7 +610,7 @@ void Dialog_Partition_Info::Display_Info()
 	               top++, bottom++,
 	               Gtk::FILL );
 
-	if ( partition.filesystem != FS_UNALLOCATED && partition .status != GParted::STAT_NEW )
+	if (partition.filesystem != FS_UNALLOCATED && partition.status != STAT_NEW)
 	{
 		// name
 		table->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Name:") ) + "</b>"),
@@ -655,10 +667,6 @@ void Dialog_Partition_Info::Display_Info()
 
 Dialog_Partition_Info::~Dialog_Partition_Info()
 {
-	this ->get_colormap() ->free_color( color_used ) ;
-	this ->get_colormap() ->free_color( color_unused ) ;
-	this ->get_colormap() ->free_color( color_text ) ;
-	this ->get_colormap() ->free_color( color_partition ) ;
 }
 
 } //GParted
