@@ -109,12 +109,12 @@ void Dialog_Rescue_Data::create_list_of_fs()
 
 	for(unsigned int i=0;i<this->partitions.size();i++)
 	{
-		if(this->partitions[i].filesystem==GParted::FS_UNALLOCATED
-			|| this->partitions[i].filesystem==GParted::FS_UNKNOWN
-			|| this->partitions[i].filesystem==GParted::FS_UNFORMATTED
-			|| this->partitions[i].filesystem==GParted::FS_EXTENDED
-			|| this->partitions[i].type==GParted::TYPE_EXTENDED
-			|| this->partitions[i].type==GParted::TYPE_UNALLOCATED)
+		if (this->partitions[i].filesystem == FS_UNALLOCATED   ||
+		    this->partitions[i].filesystem == FS_UNKNOWN       ||
+		    this->partitions[i].filesystem == FS_UNFORMATTED   ||
+		    this->partitions[i].filesystem == FS_EXTENDED      ||
+		    this->partitions[i].type       == TYPE_EXTENDED    ||
+		    this->partitions[i].type       == TYPE_UNALLOCATED   )
 		{
 			continue;
 		}
@@ -217,12 +217,7 @@ void Dialog_Rescue_Data::open_ro_view(Glib::ustring mountPoint)
 
 	gscreen = gdk_screen_get_default() ;
 
-#ifdef HAVE_GTK_SHOW_URI
 	gtk_show_uri( gscreen, uri .c_str(), gtk_get_current_event_time(), &error ) ;
-#else
-	Glib::ustring command = "gnome-open " + uri ;
-	gdk_spawn_command_line_on_screen( gscreen, command .c_str(), &error ) ;
-#endif
 
 	if ( error != NULL )
 	{
@@ -334,7 +329,7 @@ void Dialog_Rescue_Data::read_partitions_from_buffer()
 			Glib::ustring dev_path=this->device_path;
 			Glib::ustring part_path;
 			int part_num;
-			PartitionType type=GParted::TYPE_PRIMARY;
+			PartitionType type = TYPE_PRIMARY;
 			FSType fs = FS_UNALLOCATED;
 			Sector sec_start=0;
 			Sector sec_end=0;
@@ -363,14 +358,14 @@ void Dialog_Rescue_Data::read_partitions_from_buffer()
 					{
 						case 0x83: //FS code for ext2, reiserfs and xfs
 						{
-							fs=GParted::FS_EXT2;
+							fs = FS_EXT2;
 							break;
 						}
 						case 0x18:
 						case 0x82:
 						case 0xB8: //SWAP partition
 						{
-							fs=GParted::FS_LINUX_SWAP;
+							fs = FS_LINUX_SWAP;
 							break;
 						}
 						case 0x04:
@@ -378,31 +373,31 @@ void Dialog_Rescue_Data::read_partitions_from_buffer()
 						case 0x86:
 						case 0xE4: //FAT16
 						{
-							fs=GParted::FS_FAT16;
+							fs = FS_FAT16;
 							break;
 						}
 						case 0x0B:
 						case 0x0C: //FAT32
 						{
-							fs=GParted::FS_FAT32;
+							fs = FS_FAT32;
 							break;
 						}
 						case 0x07: //NTFS, HPFS, exFAT and UDF
 						{
-							fs=GParted::FS_NTFS;
+							fs = FS_NTFS;
 							break;
 						}
 						case 0x05:
 						case 0x0F:
 						case 0x85: //Extended
 						{
-							fs=GParted::FS_EXTENDED;
-							type=GParted::TYPE_EXTENDED;
+							fs = FS_EXTENDED;
+							type = TYPE_EXTENDED;
 							break;
 						}
 						default:
 						{
-							fs=GParted::FS_UNKNOWN;
+							fs = FS_UNKNOWN;
 						}
 					}
 				}
@@ -424,7 +419,7 @@ void Dialog_Rescue_Data::read_partitions_from_buffer()
 			}
 
 			//Swap partitions don't contain data
-			if(fs==GParted::FS_LINUX_SWAP)
+			if (fs == FS_LINUX_SWAP)
 			{
 				continue;
 			}
