@@ -17,6 +17,13 @@
 
 #include "Frame_Resizer_Extended.h"
 
+#include <gdkmm/general.h>
+
+
+namespace GParted
+{
+
+
 Frame_Resizer_Extended::Frame_Resizer_Extended()
 {
 }
@@ -123,8 +130,8 @@ bool Frame_Resizer_Extended::drawingarea_on_mouse_motion( GdkEventMotion * ev )
 				}
 			}
 		}
-		
-		Draw_Partition() ;
+
+		redraw();
 	}
 	
 	//check if pointer is over a gripper
@@ -151,30 +158,38 @@ bool Frame_Resizer_Extended::drawingarea_on_mouse_motion( GdkEventMotion * ev )
 	return true ;
 }
 
-void Frame_Resizer_Extended::Draw_Partition() 
+
+void Frame_Resizer_Extended::draw_partition(const Cairo::RefPtr<Cairo::Context>& cr)
 {
-	//i couldn't find a clear() for a pixmap, that's why ;)
-	gc_pixmap ->set_foreground( color_background );
-	pixmap ->draw_rectangle( gc_pixmap, true, 0, 0, 536, 50 );
-	
-	//the two rectangles on each side of the partition
-	gc_pixmap ->set_foreground( color_arrow_rectangle );
-	pixmap ->draw_rectangle( gc_pixmap, true, 0, 0, 10, 50 );
-	pixmap ->draw_rectangle( gc_pixmap, true, 526, 0, 10, 50 );
-	
-	//used
-	gc_pixmap ->set_foreground( color_used );
-	pixmap ->draw_rectangle( gc_pixmap, true, USED_START + BORDER, BORDER, USED, 34 );
-	
-	//partition
-	gc_pixmap ->set_foreground( color_partition );
+	// Background color
+	Gdk::Cairo::set_source_color(cr, color_background);
+	cr->rectangle(0, 0, 536, 50);
+	cr->fill();
+
+	// The two rectangles on each side of the partition
+	Gdk::Cairo::set_source_color(cr, color_arrow_rectangle);
+	cr->rectangle(0, 0, 10, 50);
+	cr->fill();
+	cr->rectangle(526, 0, 10, 50);
+	cr->fill();
+
+	// Used
+	Gdk::Cairo::set_source_color(cr, color_used);
+	cr->rectangle(USED_START + BORDER, BORDER, USED, 34);
+	cr->fill();
+
+	// Partition
+	Gdk::Cairo::set_source_color(cr, color_partition);
 	for( short t = 0; t < 9 ; t++ )
-		pixmap ->draw_rectangle( gc_pixmap, false, X_START +t, t, X_END - X_START -t*2, 50 - t*2 );
-			
-	//resize grips
-	Draw_Resize_Grip( ARROW_LEFT ) ;
-	Draw_Resize_Grip( ARROW_RIGHT ) ;
-	
-	//and draw everything to "real" screen..
-	drawingarea .get_window() ->draw_drawable( gc_drawingarea, pixmap, 0, 0, 0, 0 ) ;
+	{
+		cr->rectangle(X_START + t + 0.5, t + 0.5, X_END - X_START - t*2, 50 - t*2);
+		cr->stroke();
+	}
+
+	// Resize grips
+	draw_resize_grip(cr, ARROW_LEFT);
+	draw_resize_grip(cr, ARROW_RIGHT);
 }
+
+
+} //GParted
