@@ -38,10 +38,10 @@ void Partition::Reset()
 {
 	path.clear();
 	messages .clear() ;
-	status = GParted::STAT_REAL ;
-	type = GParted::TYPE_UNALLOCATED ;
+	status = STAT_REAL;
+	type = TYPE_UNALLOCATED;
 	alignment = ALIGN_STRICT ;
-	filesystem = GParted::FS_UNALLOCATED ;
+	filesystem = FS_UNALLOCATED;
 	have_filesystem_label = false;
 	uuid .clear() ;
 	name.clear();
@@ -52,6 +52,7 @@ void Partition::Reset()
 	sector_size = 0 ;
 	fs_block_size = -1;
 	inside_extended = busy = strict_start = false ;
+	fs_readonly = false;
 	logicals .clear() ;
 	flags .clear() ;
 	mountpoints .clear() ;
@@ -192,8 +193,8 @@ void Partition::Set_Unallocated( const Glib::ustring & device_path,
 	     sector_size,
 	     inside_extended,
 	     false ); 
-	
-	status = GParted::STAT_REAL ;
+
+	status = STAT_REAL;
 }
 
 void Partition::set_unpartitioned( const Glib::ustring & device_path,
