@@ -57,16 +57,16 @@ TreeView_Detail::TreeView_Detail()
 	// Tree view column "File System"; add file system text cell.
 	get_column( 2 )->pack_start( treeview_detail_columns.filesystem, true );
 	// Color pixbuf cell is left aligned.
-	get_column( 2 )->get_first_cell_renderer()->property_xalign() = Gtk::ALIGN_LEFT;
+	get_column(2)->get_first_cell()->property_xalign() = Gtk::ALIGN_START;
 	// File system text cell is left aligned.
 	std::vector<Gtk::CellRenderer*> renderers = get_column( 2 )->get_cell_renderers();
 	Gtk::CellRendererText *cell_renderer_text = dynamic_cast<Gtk::CellRendererText*>( renderers.back() );
-	cell_renderer_text ->property_xalign() = Gtk::ALIGN_LEFT ;
+	cell_renderer_text->property_xalign() = Gtk::ALIGN_START;
 
 	// Tree view column "Mount Point", make column resizable and show too wide text
 	// with ellipsis.
 	get_column( 3 )->set_resizable( true );
-	cell_renderer_text = dynamic_cast<Gtk::CellRendererText *>( get_column( 3 )->get_first_cell_renderer() );
+	cell_renderer_text = dynamic_cast<Gtk::CellRendererText *>(get_column(3)->get_first_cell());
 	cell_renderer_text->property_ellipsize() = Pango::ELLIPSIZE_END;
 
 	//set alignment of numeric columns to right
@@ -123,7 +123,7 @@ void TreeView_Detail::load_partitions( const PartitionVector & partitions,
 		row = parent_row ? *( treestore_detail ->append( parent_row .children() ) ) : *( treestore_detail ->append() ) ;
 		create_row( row, partitions[i], show_names, show_mountpoints, show_labels );
 
-		if ( partitions[ i ] .type == GParted::TYPE_EXTENDED )
+		if (partitions[i].type == TYPE_EXTENDED)
 			load_partitions( partitions[i].logicals, show_names, show_mountpoints, show_labels, row );
 	}
 }
@@ -174,7 +174,7 @@ void TreeView_Detail::create_row( const Gtk::TreeRow & treerow,
 	treerow[ treeview_detail_columns .path ] = partition .get_path() ;
 
 	//this fixes a weird issue (see #169683 for more info)
-	if ( partition .type == GParted::TYPE_EXTENDED && partition .busy ) 
+	if (partition.type == TYPE_EXTENDED && partition.busy)
 		treerow[ treeview_detail_columns .path ] = treerow[ treeview_detail_columns .path ] + "   " ;
 
 	// name
