@@ -52,10 +52,10 @@ FS linux_swap::get_filesystem_support()
 
 	if ( ! Glib::find_program_in_path( "mkswap" ) .empty() )
 	{
-		fs .create = GParted::FS::EXTERNAL ;
-		fs .create_with_label = GParted::FS::EXTERNAL ;
-		fs .grow = GParted::FS::EXTERNAL ;
-		fs .shrink = GParted::FS::EXTERNAL ;
+		fs.create = FS::EXTERNAL;
+		fs.create_with_label = FS::EXTERNAL;
+		fs.grow = FS::EXTERNAL;
+		fs.shrink = FS::EXTERNAL;
 		fs.copy = FS::EXTERNAL;
 		fs.move = FS::EXTERNAL;
 	}
