@@ -16,6 +16,7 @@
  */
 
 #include "reiserfs.h"
+#include "FileSystem.h"
 #include "Partition.h"
 
 namespace GParted
@@ -29,7 +30,7 @@ FS reiserfs::get_filesystem_support()
 
 	if ( ! Glib::find_program_in_path( "debugreiserfs" ) .empty() )
 	{
-		fs .read = GParted::FS::EXTERNAL ;
+		fs.read = FS::EXTERNAL;
 		fs .read_label = FS::EXTERNAL ;
 	}
 
@@ -42,26 +43,26 @@ FS reiserfs::get_filesystem_support()
 
 	if ( ! Glib::find_program_in_path( "mkreiserfs" ) .empty() )
 	{
-		fs .create = GParted::FS::EXTERNAL ;
-		fs .create_with_label = GParted::FS::EXTERNAL ;
+		fs.create = FS::EXTERNAL;
+		fs.create_with_label = FS::EXTERNAL;
 	}
-	
+
 	if ( ! Glib::find_program_in_path( "reiserfsck" ) .empty() )
-		fs .check = GParted::FS::EXTERNAL ;
-		
+		fs.check = FS::EXTERNAL;
+
 	//resizing is a delicate process ...
 	if ( ! Glib::find_program_in_path( "resize_reiserfs" ) .empty() && fs .check )
 	{
-		fs .grow = GParted::FS::EXTERNAL ;
-		
+		fs.grow = FS::EXTERNAL;
+
 		if ( fs .read ) //needed to determine a min file system size..
-			fs .shrink = GParted::FS::EXTERNAL ;
+			fs.shrink = FS::EXTERNAL;
 	}
 
 	if ( fs .check )
 	{
-		fs .copy = GParted::FS::GPARTED ;
-		fs .move = GParted::FS::GPARTED ;
+		fs.copy = FS::GPARTED;
+		fs.move = FS::GPARTED;
 	}
 
 	fs .online_read = FS::GPARTED ;
@@ -71,8 +72,8 @@ FS reiserfs::get_filesystem_support()
 #endif
 
 	//Actual minimum is at least 18 blocks larger than 32 MiB for the journal offset
-	fs .MIN = 34 * MEBIBYTE ;
-	
+	fs_limits.min_size = 34 * MEBIBYTE;
+
 	return fs ;
 }
 
